==> dl.php?src=linea21_2_3_0.zip: linea21/dashboard/menurub.php <==
<?php
/**
 * Dashboard module
 * 
 * Set-up module related menu in back-office
 * 
 * @package linea21\modules\dashboard
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$rub_link_add=$rub_link."&amp;todo=add";
$rub_link_list=$rub_link."&amp;todo=list&amp;scale_id=";
$rub_link_mod=$rub_link."&amp;todo=mod";
$rub_link_det=$rub_link."&amp;todo=det";
$rub_link_sup=$rub_link."&amp;todo=sup";
$rub_link_rap=$rub_link."&amp;todo=report&amp;scale_id=";
$search="search.php?rub=".$rub;
if($todo=='add') $title=_t('dashboard','add');
if($todo=='list') $title=_t('dashboard','list');
if($todo=='mod') $title=_t('dashboard','mod');
if($todo=='sup') $title=_t('dashboard','sup');
if($todo=='det') $title=_t('dashboard','det');
if($todo=='report') $title=_t('dashboard','rap');
?>
<div id="itemenu">
	<h1><?php echo $title; ?></h1>
	<div class="contentlink">
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_dashboard.menu_start'));?>
		<?php if($l21auth->hasRight('dashboard')) { ?>
		<a	href="<?php echo $rub_link_rap.$scale_id; ?>" title="<?php echo _t('export','action');?>"><i class="icon-export"></i><?php echo _t('export','action');?></a>
		<a href="<?php echo $rub_link_list.$scale_id; ?>" title="<?php echo _t('dashboard','list');?>"><i class="icon-list"></i><?php echo _t('dashboard','list');?></a>
		<a href="<?php echo $search; ?>" title="<?php echo _t('menu','search');?>"><i class="icon-search"></i><?php echo _t('menu','search');?></a>
		<?php } ?>
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_dashboard.menu_end'));?>
</div>
</div>

==> dl.php?src=linea21_2_8_0.zip: linea21/dashboard/menurub.php <==
<?php
/**
 * Dashboard module
 * 
 * Set-up module related menu in back-office
 * 
 * @package linea21\modules\dashboard
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$rub_link_add=$rub_link."&amp;todo=add";
$rub_link_list=$rub_link."&amp;todo=list&amp;scale_id=";
$rub_link_mod=$rub_link."&amp;todo=mod";
$rub_link_det=$rub_link."&amp;todo=det";
$rub_link_sup=$rub_link."&amp;todo=sup";
$rub_link_rap=$rub_link."&amp;todo=report&amp;scale_id=";
$search="search.php?rub=".$rub;
if($todo=='add') $title=_t('dashboard','add');
if($todo=='list') $title=_t('dashboard','list');
if($todo=='mod') $title=_t('dashboard','mod');
if($todo=='sup') $title=_t('dashboard','sup');
if($todo=='det') $title=_t('dashboard','det');
if($todo=='report') $title=_t('dashboard','rap');
?>
<div id="itemenu">
	<h1><?php echo $title; ?></h1>
	<div class="contentlink">
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_dashboard.menu_start'));?>
		<?php if($l21auth->hasRight('dashboard')) { ?>
		<a	href="<?php echo $rub_link_rap.$scale_id; ?>" title="<?php echo _t('export','action');?>" class="export-link"><?php echo _t('export','action');?></a>
		<a href="<?php echo $rub_link_list.$scale_id; ?>" title="<?php echo _t('dashboard','list');?>" class="list-link"><?php echo _t('dashboard','list');?></a>
		<a href="<?php echo $search; ?>" title="<?php echo _t('menu','search');?>" class="search-link"><?php echo _t('menu','search');?></a>
		<?php } ?>
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_dashboard.menu_end'));?>
</div>
</div>
